Examples
========

This section contains practical examples of using DataLib for various data analysis tasks.

Basic Examples
-------------

.. toctree::
   :maxdepth: 1

   basic/data_loading
   basic/data_cleaning
   basic/visualization

Advanced Examples
---------------

.. toctree::
   :maxdepth: 1

   advanced/regression
   advanced/classification
   advanced/clustering

Real-World Examples
-----------------

.. toctree::
   :maxdepth: 1

   real_world/stock_analysis
   real_world/customer_segmentation
   real_world/sales_prediction

Note: More examples will be added in future releases. 